evroc storage bucket copy

Copy file/object to/from a bucket

Synopsis

Copy file/object to/from a bucket

evroc storage bucket copy [flags]

Examples


	# Copy a local file to a bucket object
	evroc storage bucket copy --from /path/to/local/file --to bucket://id-of-bucket/object

	# Copy a bucket object to a local file
	evroc storage bucket copy --from bucket://id-of-bucket/object --to /path/to/local/file

	# Copy a bucket object to another bucket object
	evroc storage bucket copy --from bucket://id-of-bucket/object --to bucket://id-of-bucket/object
	

Options

  -f, --from string                   Path to the object to copy: either a local file or a bucket object
  -h, --help                          help for copy
      --max-concurrent-requests int   The maximum number of concurrent requests (default 5)
      --s3-credentials string         Path to the S3 credentials file (default "~/.evroc/credentials.ini")
  -t, --to string                     Path to the object to copy to: either a local file or a bucket object

Options inherited from parent commands

      --config string   Path to the evroc config file (default "~/.evroc/config.yaml")

SEE ALSO